function [ condileg, condmonom ] = condspecgal( sigma, N )
% Returns the spectral condition number of the Galerkin matrix arrising
% from the poly. spectral Galerkin of the bilinear form 
% a(u,v)=Integral([0,1],sigma(x)u'(x)v'(x)dx for intergrated Legendre 
% and monomials of order N.

% Get modified quadrature points
m = N+1; 
[zeta,w] = gaussquad(m);
omega = w'.*sigma((zeta'+1)/2)*2;

% Build Galerking matrices for Int. Legendre
[V,M] = intlegpol(N+1,zeta'); 
A_intleg = V(2:N+1,:)*diag(omega)*V(2:N+1,:)';

% Build Galerking matrices for Monomials
[B,DB] = monpol(N+1,zeta'); 
A_monom = DB(1:N,:)*diag(omega)*DB(1:N,:)';

% Compute condition numbers
eigvals = eig(A_intleg);
condileg = max(eigvals)/min(eigvals);
eigvals = eig(A_monom);
condmonom = max(eigvals)/min(eigvals);

end

