function [nvals, linferrs, ltwoerrs, energyerrs] = errors_p1(nvals)

    linferrs = zeros(size(nvals));
    ltwoerrs = zeros(size(nvals));
    energyerrs = zeros(size(nvals));

    i = 1;
    for dofs = nvals,

        h = 2*pi/(dofs+1);

        % Compute solution
        extmesh = linspace(-pi, pi, dofs+2);
        extU = linfegalerkinsol(-pi, pi, 1, @sin, dofs);

        % L-Inf error
        xpts = 2*pi*(0:4*dofs)/(4*dofs)-pi;
        err = abs(linterp(extmesh, extU, xpts) - 0.5*sin(xpts));
        linferrs(i) = max(err);

        % L2 error
        % shift the mesh by h/2 so that we evaluate the error in the middle of each cell.
        xpts = repmat(extmesh(1:length(extmesh)-1)+h/2,2,1); xpts = xpts(:);
        gqpts = repmat([-1;1]/sqrt(3),1,dofs+1)*h/2; gqpts = gqpts(:) + xpts;
        ltwoerrs(i) = sqrt(sum((h/2)*(linterp(extmesh, extU, gqpts) - 0.5*sin(gqpts')).^2));

        % Energy error
        derivs = repmat(extU(2:end) - extU(1:end-1),1,2); derivs = derivs';
        derivs = derivs(:)/h - 0.5*cos(gqpts);
        energyerrs(i) = sqrt(sum((h/2)*derivs.^2));

        i = i+1;

    end;

    clf;
    loglog(nvals, linferrs, 'bo-'); hold on;
    p = polyfit(log(nvals), log(linferrs), 1);
    disp(sprintf('L-Inf error algebraic with rate %f', -p(1)));

    plot(nvals, ltwoerrs, 'ro-');
    p = polyfit(log(nvals), log(ltwoerrs), 1);
    disp(sprintf('L2 error algebraic with rate %f', -p(1)));

    plot(nvals, energyerrs, 'go-');
    p = polyfit(log(nvals), log(energyerrs), 1);
    disp(sprintf('Energy error algebraic with rate %f', -p(1)));

    grid on;
    xlabel('Degrees of freedom');
    ylabel('Error');
    legend('L-Inf', 'L2', 'Energy');

end
