function [nvals, linferrs, ltwoerrs, energyerrs] = errors_p2(nvals)

    linferrs = zeros(size(nvals));
    ltwoerrs = zeros(size(nvals));
    energyerrs = zeros(size(nvals));

    e = exp(1);
    exactsol = @(x) (1-exp(-x))/(e-1) - exp(-x).*x;
    exactsolderiv = @(x) exp(-x).*(x + 1/(e-1) - 1);

    i = 1;
    for dofs = nvals

        p = dofs - 1;

        % L-Inf error
        xpts = (0:10^p-1)/(10^p-1);
        [u,dudx] = lin2pbvpspecgal(@(x)exp(x), @(x)-1, dofs, xpts);
        linferrs(i) = max(abs(u - exactsol(xpts)));

        % L2 error
        [x,w] = gaussquad(2*p); x = (x'+1)/2; w = w'/2;
        [u,dudx] = lin2pbvpspecgal(@(x)exp(x), @(x)-1, dofs, x);
        ltwoerrs(i) = sqrt(sum(w.*(u - exactsol(x)).^2));

        % Energy error
        energyerrs(i) = sqrt(sum(w.*exp(x).*(dudx - exactsolderiv(x)).^2));

        i = i+1;

    end

    %linferrs
    %ltwoerrs
    %energyerrs
plot(nvals,linferrs,'r');
    %semilogy(nvals, linferrs);
    p = polyfit(log(nvals), log(-log(linferrs)), 1);
    disp(sprintf('L-Inf error exponential with gamma = %f and delta = %f', exp(p(2)), p(1)));

    %semilogy(nvals, ltwoerrs);
    p = polyfit(log(nvals), log(-log(ltwoerrs)), 1);
    disp(sprintf('L2 error exponential with gamma = %f and delta = %f', exp(p(2)), p(1)));

    %semilogy(nvals, energyerrs);
    p = polyfit(log(nvals), log(-log(energyerrs)), 1);
    disp(sprintf('Energy error exponential with gamma = %f and delta = %f', exp(p(2)), p(1)));

end
