  function u = lin2pbvpspecgal_mon(sigma,g,N,x)
% Polynomial spectral Galerkin discretization of linear 2nd-order two-point BVP 
% \Blue{$-\frac{d}{dx}(\sigma(x)\frac{du}{dx})=g(x)$}, \Blue{$u(0) = u(1) = 0 $}
% on \Blue{$\Omega = [0,1]$}. Trial space of dimension \Blue{$N$}. 
% Values of approximate solution in points \Blue{$x_j$} are returned in the row vector \texttt{u}
% This version uses monomials as basis functions.

m = N+1;                 % Number of quadrature nodes
[zeta,w] = gaussquad(m); % Obtain Gauss quadrature nodes w.r.t \Blue{$[-1,1]$}

% Compute values of monomials at Gauss nodes
[B,DB] = monpol(N+1,zeta'); 
omega = w'.*sigma((zeta'+1)/2)*2;       % Modified quadrature weights
A = DB(1:N,:)*diag(omega)*DB(1:N,:)'; % Assemble Galerkin matrix
phi = B*(0.5*w'.*g((zeta'+1)/2))';      % Assemble right hand side vector
mu = A\phi;                             % Solve linear system

% Compute values or monomiqlw polynomials at output points
[B,DB] = monpol(N+1,2*x-1); u = mu'*B;

