function u = linfegalerkinsol(a, b, c, g, N)
% Computes the values of the discrete Galerkin solution using as  
% basis tent functions on the domain [a,b] for the problem
% Integral(u'v' + cuv) = Integral(gv), for the given function
% handle g and using a mesh with N internal nodes. 
% The function is constrained by the following boundary conditions
% u(a)=0 and u(b)=0

% mesh
h = (b-a)/(N+1);
x = linspace(a,b,N+2)';

% compute finite element matrix A and right-hand side phi
v1 = (-1/h + 1/6*c*h)*ones(N+1,1);
v2 = [1/h + 1/3*c*h; (2/h + 2/3*c*h)*ones(N,1); 1/h + 1/3*c*h];
A = gallery('tridiag',v1,v2,v1);      
phi = h*[0.5*g(x(1)); g(x(2:end-1)); 0.5*g(x(end))];

% incorporate boundary data
u = zeros(N+2,1);

% solve the linear system
u(2:end-1) = A(2:end-1,2:end-1)\phi(2:end-1);

return
