nvals = 2.^(1:10);
M = 10^5;
inside = @(x) abs(x-0.5) < 0.25;
outside = @(x) 1 - inside(x);
sigma = @(x) (1+inside(x)).*ones(size(x));
f = @(x) ones(size(x));
temp = @(x) 0.25*x - 0.25*x.^2;
exact = @(x) (1+outside(x)).*temp(x) + inside(x).*ones(size(x))*3/64;

xpts = linspace(0,1,M+1)';
xpts = xpts(2:end-1);

l2err = [];
lierr = [];

for N = nvals
    A = getGalMat(sigma, N);
    L = getrhsvector(f, N);
    mu = A \ L;

    approx = [evaltrigsum(mu, M)];
    err = abs(approx - exact(xpts));

    l2err = [l2err; sqrt(sum(err.^2)/M)];
    lierr = [lierr; max(err)];
end 

loglog(nvals, lierr, 'bo-');
hold on; grid on;
plot(nvals, l2err, 'ro-');
xlim([1, 2000]);
xlabel('N');
ylabel('Error');
legend('L^\infty', 'L^2');

P = polyfit(log(nvals), log(lierr'), 1);
disp(['L-inf convergence algebraic with rate: ' num2str(-P(1))]);
P = polyfit(log(nvals), log(l2err'), 1);
disp(['L-2 convergence algebraic with rate: ' num2str(-P(1))]);
