function [mu_new,figsol] = solvebrachlin(init_guess,tol)
% M intervals, M-1 interior nodes
M = length(init_guess)-1;
h= 1/M; %meshwidth


figsol = figure; hold on;
maxiter=10000;
mu_new = init_guess;
t = [];
for k=1:maxiter
    mu = mu_new;
    % Plot shape of string
    plot(mu(1,:), mu(2,:),'--g'); drawnow;
    title(sprintf('M = %d, iteration #%d', M,k));
    xlabel('{\bf x_1}'); ylabel('{\bf x_2}');
    t = [t; traveltime(mu)];
  
    R = Rmat(mu);
    % Computation of right hand side
    phi = rhs(mu);
    phi1 = phi(1,:);
    phi2 = phi(2,:);

    % Modify right hand side to take in account to the offset function
    phi1(1)= phi1(1) + R(1,1)*mu(1,1);
    phi1(M-1) = phi1(M-1) +R(M+1,M+1)*mu(1,end);
    phi2(1) = phi2(1) + R(1,1)*mu(2,1);
    phi2(M-1) = phi2(M-1) +R(M+1,M+1)*mu(2,end);

    % Solve linear system and compute new iterate
    mu_new = [mu(:,1),[(R((2:end-1),(2:end-1))\phi1')';
                (R((2:end-1),(2:end-1))\phi2')'],mu(:,end)];
    % Check simple termination criterion for fixed point iteration.
    if (norm(mu_new - mu,'fro') < tol*norm(mu_new,'fro')/M)
        plot(mu_new(1,:),mu_new(2,:),'r'); 
        xi = linspace(0,1);
        plot(pi*xi-sin(pi*xi),cos(pi*xi)-1,'b');
    break;
    end

end
    figure
    plot(t);